@@ -27,7 +27,6 @@
 #include <QDir>
 
 #include "rocsversion.h"
-#include "logging_p.h"
 #include "ui/mainwindow.h"
 
 int main(int argc, char *argv[])
@@ -42,7 +41,7 @@ int main(int argc, char *argv[])
     aboutData.setShortDescription(ki18nc("@title Short program description", "Graph Theory Simulator").toString());
 
     // credits and authors (in alphabetical list)
-    aboutData.addCredit(ki18nc("@info:credit", "(c) 2008-2015 Rocs Developers").toString());
+    aboutData.addCredit(ki18nc("@info:credit", "(c) 2008-2016 Rocs Developers").toString());
     aboutData.addAuthor(ki18nc("@info:credit Developer name", "Andreas Cord-Landwehr").toString(),
                         ki18nc("@info:credit Role", "Maintainer").toString(),
                         "cordlandwehr@kde.org",
@@ -56,12 +55,11 @@ int main(int argc, char *argv[])
                         "wagner.reck@gmail.com",
                         "http://wiglot.wordpress.com");
 
-    // TODO: for >=KF5.15 use KCrash::initialize();
-    KCrash::setCrashHandler(KCrash::defaultCrashHandler);
-
     QApplication app(argc, argv);
     app.setApplicationVersion(aboutData.version());
 
+    KCrash::initialize();
+
     /**
      * Create command line parser and feed it with known options
      */
